==> deepin-font-installer_1.0.4.orig.tar.xz: deepin-font-installer-1.0.4/deepin-font-installer/translations/deepin-font-installer_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Arraste o arquivo de fontes para cá</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Selecione o arquivo</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Outra versão instalada: %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Versão já instalada</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Instalador de fontes Deepin</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>O Instalador de Fontes Deepin é usado para instalar e desinstalar arquivos de fonte para os usuários com a função de instalação em massa.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Instalador de fontes Deepin</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Instalar em Massa</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Instalado com sucesso</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Ver diretório de fontes</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido(a)</translation>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Ver o diretório de fontes</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Copyright:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Mesma versão já instalada</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Instalada com sucesso</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Removida com sucesso</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Outra versão instalada: %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
</context>
</TS>

==> deepin-font-installer_1.1.orig.tar.xz: deepin-font-installer-1.1/deepin-font-installer/translations/deepin-font-installer_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Arraste o arquivo de fontes aqui</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Selecione o arquivo</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Outra versão instalada: %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Versão já instalada</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Instalador de Fontes</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>O Instalador de Fontes é usado para instalar e desinstalar arquivos de fonte para os usuários com a função de instalação em massa.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Instalador de Fontes</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Instalar em Massa</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Instalado com sucesso</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Ver diretório de fontes</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation>Atualizando cache de fontes, aguarde...</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Ver o diretório de fontes</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Copyright:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Mesma versão já instalada</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Instalada com sucesso</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Removida com sucesso</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Outra versão instalada: %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
</context>
</TS>
